@@ -6,8 +6,6 @@
 #'                Either single vectors, a complete data frame or a list of
 #'                variables can be dichotomized.
 #'
-#' @param x Variable (vector), \code{data.frame} or \code{list} of variables
-#'          that should be dichotomized
 #' @param dich.by Indicates the split criterion where a variable is dichotomized.
 #'          Must be one of the following values (may be abbreviated):
 #'          \describe{
@@ -20,11 +18,12 @@
 #'          attributes of dichotomized variable (see \code{\link{set_labels}}).
 #'          If \code{NULL} (default), no value labels will be set.
 #' @inheritParams rec
+#'
 #' @return A dichotomized factor (or numeric, if \code{as.num = TRUE}) variable (0/1-coded),
 #'           respectively a data frame or list of dichotomized factor (or numeric) variables.
 #'
-#' @note Variable label attributes (see, for instance, \code{\link{set_label}}) are preserved
-#'         (unless changes via \code{var.label}-argument).
+#' @note Variable label attributes are preserved (unless changes via
+#'       \code{var.label}-argument).
 #'
 #' @examples
 #' data(efc)
@@ -55,7 +54,7 @@
 #'           val.labels = c("lower", "higher")))
 #'
 #' @export
-dicho <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL) {
+dicho <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL, suffix = "_d") {
   # check for correct dichotome types
   if (!is.numeric(dich.by) && !dich.by %in% c("median", "mean", "md", "m")) {
     stop("argument `dich.by` must either be `median`, `mean` or a numerical value." , call. = FALSE)
@@ -65,17 +64,20 @@ dicho <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.l
 }
 
 #' @export
-dicho.data.frame <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL) {
-  tibble::as_tibble(lapply(x, FUN = dicho_helper, dich.by, as.num, var.label, val.labels))
+dicho.data.frame <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL, suffix = "_d") {
+  tmp <- tibble::as_tibble(lapply(x, FUN = dicho_helper, dich.by, as.num, var.label, val.labels))
+  # change variable names, add suffix "_r"
+  if (!is.null(suffix) && !sjmisc::is_empty(suffix)) colnames(tmp) <- sprintf("%s%s", colnames(tmp), suffix)
+  tmp
 }
 
 #' @export
-dicho.list <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL) {
+dicho.list <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL, suffix = "_d") {
   lapply(x, FUN = dicho_helper, dich.by, as.num, var.label, val.labels)
 }
 
 #' @export
-dicho.default <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL) {
+dicho.default <- function(x, dich.by = "median", as.num = FALSE, var.label = NULL, val.labels = NULL, suffix = "_d") {
   dicho_helper(x, dich.by, as.num, var.label, val.labels)
 }
 
